ProSHADE: src/proshade/ProSHADE_data.hpp File Reference

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

Classes | Namespaces | Functions
ProSHADE_data.hpp File Reference

This is the header file containing internal data representation and manipulation structures and functions. More...

`#include "ProSHADE_spheres.hpp"`

Go to the source code of this file.

## Classes
class | ProSHADE_internal_data::ProSHADE_data
| This class contains all inputed and derived data for a single structure. More...

## Namespaces
| ProSHADE_internal_data
| This namespace contains the structure and functions required for data reading and storing their derivates.

## Functions
std::vector< std::vector< proshade_double > > | ProSHADE_internal_data::computeGroupElementsForGroup (proshade_double xAx, proshade_double yAx, proshade_double zAx, proshade_signed fold)
| This function computes the group elements as rotation matrices (except for the identity element) for any cyclic point group given as axis and fold. More...
std::vector< std::vector< proshade_double > > | ProSHADE_internal_data::joinElementsFromDifferentGroups (std::vector< std::vector< proshade_double > > *first, std::vector< std::vector< proshade_double > > *second, proshade_double matrixTolerance, bool combine)
| This function joins two group element lists using only unique elements. More...

## Detailed Description

This is the header file containing internal data representation and manipulation structures and functions.

This header file contains the ProSHADE_data class declaration as well as the declarations for simple manipulations with the data (more complex manipulations are done in dedicated source files) and caller functions for the more complex manipulations. The class described here is how ProSHADE stores the structural data internally; however, the user should not need to access any of this code manually, as changes to this structure may have large consequences unforseen by the user.

Copyright by Michal Tykac and individual contributors. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: 1) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer. 2) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution. 3) Neither the name of Michal Tykac nor the names of this code's contributors may be used to endorse or promote products derived from this software without specific prior written permission.

This software is provided by the copyright holders and contributors "as is" and any express or implied warranties, including, but not limitted to, the implied warranties of merchantibility and fitness for a particular purpose are disclaimed. In no event shall the copyright owner or the contributors be liable for any direct, indirect, incidental, special, exemplary, or consequential damages (including, but not limitted to, procurement of substitute goods or services, loss of use, data or profits, or business interuption) however caused and on any theory of liability, whether in contract, strict liability or tort (including negligence or otherwise) arising in any way out of the use of this software, even if advised of the possibility of such damage.

Author
  Michal Tykac
  Garib N. Murshudov

Version
  0.7.5.4

Date
  MAR 2021

Definition in file ProSHADE_data.hpp.